==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/DrawingPreferences/DimensionSettings/ts/DimensionSettings_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>DimensionSettings</name>
    <message>
        <location filename="../DimensionSettings.js" line="+27"/>
        <source>Defaults for New Drawings</source>
        <translation>Privzeto za nove risbe</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+2"/>
        <source>Dimension Settings</source>
        <translation>Nastavitve dimenzij</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Dimension</source>
        <translation>Dimenzija</translation>
    </message>
    <message>
        <location line="+107"/>
        <source>Scientific</source>
        <translation>Znanstveno</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal</source>
        <translation>Desetiški</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Engineering</source>
        <translation>Inženirski</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectural</source>
        <translation>Arhitekturen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fractional</source>
        <translation>Frakcijski</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Decimal Degrees</source>
        <translation>Stopinje v desetiškem</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Deg/min/sec</source>
        <translation>Stopinj/Minut/sekund</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gradians</source>
        <translation>Gradiani</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Radians</source>
        <translation>Radiani</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Surveyor&apos;s units</source>
        <translation>Geodetske enote</translation>
    </message>
    <message>
        <location line="+198"/>
        <source>Unit / Format</source>
        <translation>Enota / Zapis</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The drawing unit must be &apos;Inch&apos; or &apos;Foot&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation>Enota risbe mora biti v inčih, za prikaz kotiranj ter napisov v arhitekturni ali inžinerski obliki. Zapis spremenljen v desetiški.</translation>
    </message>
    <message>
        <source>The drawing unit must be &apos;Inch&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation type="vanished">Enota risbe mora biti v inčih, za prikaz kotiranj ter napisov v arhitekturni ali inžinerski obliki. Zapis spremenljen v desetiški.</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+29"/>
        <source>Sizes</source>
        <translation>Velikosti</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Keep proportions</source>
        <translation>Ohrani razmerja</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Text height:</source>
        <translation>Višina besedila:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line offset:</source>
        <translation>Odmik podajšane črte:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line extension:</source>
        <translation>Podaljšek podajšane črte:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Dimension line gap:</source>
        <translation>Odmik mere od kotirne črte:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Arrow size:</source>
        <translation>Velikost puščice:</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Size scale factor:</source>
        <translation>Faktor povečave:</translation>
    </message>
    <message>
        <location line="+38"/>
        <source>Arrow Style</source>
        <translation>Slog puščice</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Arrow</source>
        <translation>Puščica</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Architectural Tick</source>
        <translation>Arhitekturna poševnica</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Font</source>
        <translation>Pisava</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Dimension label font:</source>
        <translation>Pisava kotiranj:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Label Format</source>
        <translation>Oblika napisov</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Linear Dimensions</source>
        <translation>Linearne mere</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Format:</source>
        <translation>&amp;Oblika:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>P&amp;recision:</source>
        <translation>Na&amp;tančnost:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+60"/>
        <source>Show trailing zeros</source>
        <translation>Prikaži tudi ničle</translation>
    </message>
    <message>
        <location line="-50"/>
        <source>Angular Dimensions</source>
        <translation>Zapisi kotov</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>F&amp;ormat:</source>
        <translation>O&amp;blika:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Pre&amp;cision:</source>
        <translation>Nata&amp;nčnost:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+19"/>
        <source>Preview</source>
        <translation>Predogled</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/DrawingPreferences/DimensionSettings/ts/DimensionSettings_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>DimensionSettings</name>
    <message>
        <location filename="../DimensionSettings.js" line="+27"/>
        <source>Defaults for New Drawings</source>
        <translation>Privzeto za nove risbe</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+2"/>
        <source>Dimension Settings</source>
        <translation>Nastavitve dimenzij</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Dimension</source>
        <translation>Dimenzija</translation>
    </message>
    <message>
        <location line="+108"/>
        <source>point</source>
        <translation>pika</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>comma</source>
        <translation>vejica</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>space</source>
        <translation>presledek</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Scientific</source>
        <translation>Znanstveno</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal</source>
        <translation>Desetiški</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Engineering</source>
        <translation>Inženirski</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectural</source>
        <translation>Arhitekturen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fractional</source>
        <translation>Frakcijski</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Decimal Degrees</source>
        <translation>Stopinje v desetiškem</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Deg/min/sec</source>
        <translation>Stopinj/Minut/sekund</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gradians</source>
        <translation>Gradiani</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Radians</source>
        <translation>Radiani</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Surveyor&apos;s units</source>
        <translation>Geodetske enote</translation>
    </message>
    <message>
        <location line="+209"/>
        <source>Unit / Format</source>
        <translation>Enota / Zapis</translation>
    </message>
    <message>
        <source>The drawing unit must be &apos;Inch&apos; or &apos;Foot&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation type="vanished">Enota risbe mora biti v inčih, za prikaz kotiranj ter napisov v arhitekturni ali inžinerski obliki. Zapis spremenljen v desetiški.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The drawing unit must be &apos;Inch&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation>Enota risbe mora biti v inčih, za prikaz kotiranj ter napisov v arhitekturni ali inžinerski obliki. Zapis spremenljen v desetiški.</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+29"/>
        <source>Sizes</source>
        <translation>Velikosti</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Keep proportions</source>
        <translation>Ohrani razmerja</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Text height:</source>
        <translation>Višina besedila:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line offset:</source>
        <translation>Odmik podajšane črte:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line extension:</source>
        <translation>Podaljšek podajšane črte:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Dimension line gap:</source>
        <translation>Odmik mere od kotirne črte:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Arrow size:</source>
        <translation>Velikost puščice:</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Size scale factor:</source>
        <translation>Faktor povečave:</translation>
    </message>
    <message>
        <location line="+38"/>
        <source>Arrow Style</source>
        <translation>Slog puščice</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Arrow</source>
        <translation>Puščica</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Architectural Tick</source>
        <translation>Arhitekturna poševnica</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Font</source>
        <translation>Pisava</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Dimension label font:</source>
        <translation>Pisava kotiranj:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Number Format</source>
        <translation>Zapis števil</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Decimal separator:</source>
        <translation>Ločilo decimalk:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Label Format</source>
        <translation>Oblika napisov</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Linear Dimensions</source>
        <translation>Linearne mere</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Format:</source>
        <translation>&amp;Oblika:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>P&amp;recision:</source>
        <translation>Na&amp;tančnost:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+60"/>
        <source>Show trailing zeros</source>
        <translation>Prikaži tudi ničle</translation>
    </message>
    <message>
        <location line="-50"/>
        <source>Angular Dimensions</source>
        <translation>Zapisi kotov</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>F&amp;ormat:</source>
        <translation>O&amp;blika:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Pre&amp;cision:</source>
        <translation>Nata&amp;nčnost:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+19"/>
        <source>Preview</source>
        <translation>Predogled</translation>
    </message>
</context>
</TS>
